..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

==============
 Invenio-REST
==============

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-rest.svg
        :target: https://github.com/inveniosoftware/invenio-rest/blob/master/LICENSE

.. image:: https://github.com/inveniosoftware/invenio-rest/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-rest/actions

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-rest.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-rest

.. image:: https://img.shields.io/pypi/v/invenio-rest.svg
        :target: https://pypi.org/pypi/invenio-rest

REST API module for Invenio.

Invenio-REST takes care of installing basic error handling on a Flask API
application, as well as initializing Flask-CORS for Cross-Origin Resources
Sharing (not enabled by default).

Further documentation is available on
https://invenio-rest.readthedocs.io/
